from abstract_database import *
conn_mgr = connectionManager(env_path="/home/solcatcher/.env",
                  dbType='database',
                  dbName='abstract')


from py import *
req_mgr = extract_request_data()
toggle_trigger = {True: False, False: True}
ip_mgr = UserIPManager()
blacklist_mgr = BlacklistManager()
table_mgr = TableManager()
upload_mgr = UploadManager()
user_mgr = UserManager()
existing_users = user_mgr.get_existing_users()

blacklist_mgr.create_blacklist_table()

row = upload_mgr.select_upload_from_id(250)
sharable = row.get("shareable")

print(toggle_trigger[sharable])
row = upload_mgr.update_upload(
    upload_id=250,
    shareable=False,
    share_password="secret",
    download_limit=10
)
print(row)

row = upload_mgr.select_upload_from_id(250)
print(row)



from abstract_database import *
conn_mgr = connectionManager(env_path="/home/solcatcher/.env",
                  dbType='database',
                  dbName='abstract')



from py import *












from queriesManager import *
from psycopg2 import sql
import logging



def get_splits(string,splits=[],direction=0):
    for split in splits:
        nustring = string.split(split)
        string =  nustring[0]
        if len(nustring)> direction:
            string = nustring[direction]
    return string
def get_db_row_name(query):
    splits = ['FROM ','UPDATE ','CREATE TABLE IF NOT EXISTS ','INSERT INTO ']
    query = get_splits(query,splits=splits,direction=1)
    splits = [' ','\t','\n']
    row_name = get_splits(query,splits=splits,direction=0)
    return row_name
def get_kargs(*args,**kwargs):
    return kwargs
def get_row_keys(query):
    row_name = get_db_row_name(query)
    query = f"SELECT * FROM {row_name} ORDER BY RANDOM() LIMIT 1;"
    row = select_distinct_rows(query)
    keys = row[0].keys()
    return keys
def return_only_db_inputs(query,**kwargs):
    return_kwargs = {}
    input_keys = get_row_keys(query)
    for input_key in input_keys:
        if input_key in kwargs:
            return_kwargs[input_key] = kwargs.get(input_key)
    return return_kwargs

upload_mgr = UploadManager()
kwargs = get_kargs(id=250,shareable=True,share_password="secret",download_limit=10)
row = fetch_any_combo(columnNames='*',
                    tableName='uploads',
                    searchColumn='id',
                    searchValue=250,
                    count=False,
                    anyValue=False,
                    zipit=True,
                    schema='public')
input(kwargs)


query = """UPDATE uploads
            SET shareable      = %s,
            share_password = %s,
            download_limit = %s
           WHERE id = %s
           RETURNING *;
        """
input(get_row_keys(query))
row = select_distinct_rows(query,shareable, share_password, download_limit, upload_id)
input(row[0].values())
row = upload_mgr.select_upload_from_id(250)
input(row)
query = "SELECT * FROM uploads WHERE id = %s"
row = select_distinct_rows(query,upload_id)
input()
['id',
 'filename',
 'filepath',
 'uploader_id',
 'created_at',
 'shareable',
 'share_password',
 'download_count',
 'download_limit'
]




from ..imports import datetime,List, Dict
from ..query_utils import *

class BlacklistManager(BaseQueryManager):
    """Manages CRUD on uploads; all your original methods just wired up dynamically."""
    def __init__(self, logs_on: bool = True):
        self.filename = 'blacklistQueries'
        self.basename = f'{self.filename}.json'
     
        super().__init__(self.filename, logs_on=logs_on)

    def create_blacklist_table(
        self
        ) -> None:
        """Check if a user blacklist record exists in the user_blacklists table."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_create_blacklist_table
        insert_query(query)

  
    def select_blacklist_token(
        self,
        token: str
        ) -> bool:
        """Update the last_seen timestamp and increment hit_count for a user blacklist."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_select_blacklist_token
        time_now = datetime.utcnow()
        args = (token,)
        row = select_rows(query, *args)
        return row is not None

    def insert_blacklist_token(
        self,
        token: str
        ) -> None:
        """Insert a new user blacklist record into the user_blacklists table."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_insert_blacklist_token
        args = (token,)
        insert_query(query, *args)



from abstract_database import *
from abstract_database.db_utils import *
# Initialize connectionManager once (using your .env path if needed)
conn_mgr = connectionManager(env_path="/home/solcatcher/.env",
                  dbType='database',
                  dbName='abstract')
from queriesManager import *

#input(get_query_utils_dir())
#input(get_user_ip_queries_path())
#data = safe_read_from_json(get_user_ip_queries_path())
#input(data)
req_mgr = extract_request_data()
# Example of how you might use this DbManager
dbManager = DbManager()
dbUrl = conn_mgr.dburl.replace('postgres','postgresql')
db_browser = DatabaseBrowser(dbUrl=dbUrl)
table_list = db_browser.list_tables()
table_ls = []
for table in table_list:
    table_ls.append(table.split('. ')[-1])
ip_mgr = UserIPManager()
blacklist_mgr = BlacklistManager()
table_mgr = TableManager()
upload_mgr = UploadManager()
user_mgr = UserManager()
query_schemas = get_yaml_queries_data(data_type=None)
row = fetch_any_combo(tableName='users')
table_mgr = TableManager()
def replace_input_ls_item(input_ls,item):
    for i,input_item in enumerate(input_ls):
        if input_item == key:
            input_ls[i] = None
            return input_ls
def get_all_inputs_in_query(query,*args,**kwargs):
    all_tables = get_all_tables_js()
    table_name = get_db_row_name(query)
    return_kwargs = {}
    table_inputs = all_tables.get(table_name)
    kwargs_copy = kwargs.copy()
    input_ls = list(kwargs_copy.keys())
    for key,value in kwargs.items():
        if key in table_inputs:
            return_kwargs[key] = value
            del kwargs_copy[key]
            input_ls = replace_input_ls_item(input_ls,key)
    for i,arg in enumerate(args):
        target_item = None
        for j,input_item in enumerate(input_ls):
            if i <= j and input_item is not None:
                target_item = [input_item,j]
            elif  i >= j and input_item is not None or (target_item and i - target_item[-1] > j - target_item[-1]):
                target_item = [input_item,j]
        if target_item:
            input_ls = replace_input_ls_item(input_ls,target_item[0])
    return table_inputs
    
def get_all_tables_js():
    table_names = get_all_table_names()
    all_tables = {}
    for table_name in table_names:
        all_tables[table_name] = {}
        row = fetch_any_combo(columnNames='*',
                        tableName=table_name,
                        schema='public')
        if row:
            keys = list(row[0].keys())
            all_tables[table_name]['inputs'] =keys
    return all_tables
all_tables = get_all_tables_js()
for table,query_schema in query_schemas.items():
    
    
    for query_name,query in query_schema.items():
        table_inputs=get_all_inputs_in_query(query)
        input(table_inputs)
        if table_inputs is None:
            table_inputs = all_tables.get(table)
        
        table_name = get_db_row_name(query)
        db_inputs = get_table_info(query)#return_only_db_inputs(query)
        print(f"name == {table_name}\nquery_name == {query_name}\table_inputs == {table_inputs}")
        print(get_table_name_from_query(query))
        
    
    
blacklist_mgr.create_blacklist_table()
table_mgr.create_users_table()



from abstract_utilities import (
    make_list,
    SingletonMeta,
    initialize_call_log,
    safe_read_from_json)
import psycopg[binary],logging,warnings,traceback,os,yaml,logging
from psycopg[binary] import sql, connect
from psycopg.extras import RealDictCursor
from abstract_security import get_env_value
from abstract_database import *
from flask import Request
from typing import *
from datetime import datetime



from ..imports import datetime,List, Dict
from ..query_utils import *

class TableManager(BaseQueryManager):
    """Manages CRUD on uploads; all your original methods just wired up dynamically."""
    def __init__(self, logs_on: bool = True):
        self.filename = 'tableQueries'
        self.basename = f'{self.filename}.json'
     
        super().__init__(self.filename, logs_on=logs_on)

    def create_users_table(
        self
        ):
        """Check if a uploads table record exists in the uploads_tables table."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_create_users_table
        execute_query(query)
    def create_update_triggers(
        self
        ):
        """Check if a uploads table record exists in the uploads_tables table."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_create_update_triggers
        execute_query(query)
    def create_triggers(
        self
        ):
        """Check if a uploads table record exists in the uploads_tables table."""
        if self.logs_on:
            initialize_call_log()
        query = self._query_create_triggers
        execute_query(query)



from .query_utils import *
from .blacklist_queries import *
from .ip_queries import *
from .user_queries import *
from .table_queries import *
from .uploads_queries import *
from .query_utils import *
from .request_queries import *
USER_IP_MGR = UserIPManager()
BLACKLIST_MGR = BlacklistManager()
TABLE_MGR = TableManager()
UPLOAD_MGR = UploadManager()
USER_MGR = UserManager()
